@@ -45,7 +45,7 @@ package Software::License::GPL_3::or_later;
 use strict;
 use warnings;
 
-our $VERSION = '0.006_002'; # TRIAL VERSION
+our $VERSION = '0.006_003'; # TRIAL VERSION
 
 use parent 'Software::License::GPL_3';
 use Text::Wrap;
@@ -94,7 +94,7 @@ sub version { $_[ 0 ]->_version . '+'; };
 #pod * The method has optional parameter — program name (default name is "this program"). It is used in
 #pod notice text.
 #pod * It returns copyright statement followed by standard GNU 3-paragraph license notice.
-#pod * Result is formatted with `Text::Wrap::fill`.
+#pod * Result is formatted with L<Text::Wrap::fill>.
 #pod
 #pod B<Note:> Program name is an experimental feature.
 #pod
@@ -122,7 +122,7 @@ Software::License::GPL_3::or_later - GPLv3+ license for Software::License
 
 =head1 VERSION
 
-Version 0.006_002.
+Version 0.006_003.
 This is a B<trial release>.
 
 =head1 DESCRIPTION
@@ -186,7 +186,7 @@ It returns copyright statement followed by standard GNU 3-paragraph license noti
 
 =item *
 
-Result is formatted with `Text::Wrap::fill`.
+Result is formatted with L<Text::Wrap::fill>.
 
 =back
 
